<?php if(!defined('PURECLIENT_PATH')){die('Direct access not permitted');}
require_once(PURECLIENT_PATH.'/libraries/guzzle.phar');
use Guzzle\Http\Client;
		
class Publication {

	public $uuid;
	public $title;
	public $year;
	public $month;
	public $day;

	public function __construct() {
	}
	
	function get_publications($person_uuid) {
		global $wpdb;
		$options = get_option('pure_profiles_options');
		$host = $options['pure_profiles_host_settings'];
		$username = $options['pure_profiles_username_settings'];
		$password = $options['pure_profiles_password_settings'];

		/* get all publications */
		$client = new Client($host);		
		$request = $client->get('/ws/rest/publications?rendering=xml_long&associatedPersonUuids.uuid='.$person_uuid);
		$request->getCurlOptions()->set(CURLOPT_SSL_VERIFYHOST, false);
		$request->getCurlOptions()->set(CURLOPT_SSL_VERIFYPEER, false);
		$request->getCurlOptions()->set(CURLOPT_CERTINFO, false);
		$request->getCurlOptions()->set(CURLOPT_TIMEOUT, 120);

		$request->setAuth($username, $password);
		$response = $request->send();
		$xml = $response->xml();
		$namespaces = $xml->getNamespaces(true);
				
		$core = $xml->children($namespaces['core']);
			
		$retrieved = date("F j, Y, g:i a"); 
		
		for ($i=0; $i < $core->count; $i++) {
			$publication = $core->result->content[$i]->children($namespaces['publication']);
			$pub_title = $publication->title;
			$number_of_pages = $publication->numberOfPages;
			$abstract_str = "";
			if ($publication->abstract) {
				$abstract = $publication->abstract->children($namespaces['core']);
				$abstract_str = $abstract->localizedString;
			}
			$publication_date = $publication->publicationDate->children($namespaces['core']);
			$pub_attributes = $core->result->content[$i]->attributes();
			$pub_uuid = (string)$pub_attributes['uuid'];
			$volume = $publication->volume;
			$journal_number = $publication->journalNumber;
			$journal_pages = $publication->pages;
			$type_classification = $publication->typeClassification->children($namespaces['core']);
			$language = $publication->language->children($namespaces['core']);
			$language_str = $language->term->localizedString;
			$workflows = $publication->startedWorkflows->children($namespaces['core']);
			$state = $workflows->startedWorkflow->core->state;
			$dois_str = "";
			if ($publication->dois) {
				$dois = $publication->dois->children($namespaces['core']);
				$dois_array = array();
				foreach ($dois->doi->doi as $d) {
					$dois_array[] = $d;
				}
				$dois_str = implode(",",$dois_array);
			}
			$journal_title_str = "";
			$journal_issn_str = "";
			if ($publication->journal) {
				$journal = $publication->journal->children($namespaces['journal']);
				$journal_title = $journal->title->children($namespaces['extensions']);
				$journal_title_str = $journal_title->string;
				if ($journal->issn) {
					$journal_issn = $journal->issn->children($namespaces['extensions']);
					$journal_issn_str = $journal_issn->string;
				}
			}
						
			/* insert publications into table */
			$table_name = $wpdb->prefix . "pure_profiles_publication";
			$rows_affected = $wpdb->insert( $table_name, array( 
				'uuid' => $pub_uuid, 
				'title' => $pub_title, 
				'abstract' => $abstract_str,
				'originallanguage' => $language_str,
				'state' => $state,
				'dois' => $dois_str,
				'numberofpages' => $number_of_pages,
				'personuuid' => $person_uuid, 
				'publicationyear' => $publication_date->year,
				'publicationmonth' => $publication_date->month, 
				'publicationday' => $publication_date->day, 
				'volume' => $volume,
				'journalnumber' => $journal_number,
				'journalpages' => $journal_pages,
				'journaltitle' => $journal_title_str,
				'journalissn' => $journal_issn_str,
				'retrieved' => $retrieved
			));
											
											
			$personAssociations = $publication->persons->children($namespaces['person']);
			$personAssociationsCount = count($personAssociations);
								
			for ($j=0; $j < $personAssociationsCount; $j++) {
			
				$associated_person_uuid = "";
				$first_name = "";
				$last_name = "";
				
				$person = $personAssociations[$j]->children($namespaces['person']);

				if ($person->person) {
					/* person is in Pure */
					$personAttributes = $person->person->attributes();
					$associated_person_uuid = $personAttributes->uuid;
					if ($person->person->name) {
						$person_name = $person->person->name->children($namespaces['core']);
						$first_name = ($person_name->firstName) ? $person_name->firstName : ""; 
						$last_name = ($person_name->lastName) ? $person_name->lastName : "";					
					}						
				} else {
					/* person is not in Pure */	
					if ($person->name) {
						$person_name = $person->name->children($namespaces['core']);
						$first_name = ($person_name->firstName) ? $person_name->firstName : ""; 
						$last_name = ($person_name->lastName) ? $person_name->lastName : "";					
					}		
				}

				$person_role = $person->personRole->children($namespaces['core']);
				$person_role_str = $person_role->term->localizedString;
				
				// insert person associations into table 
				$table_name = $wpdb->prefix . "pure_profiles_publication_person";
				$rows_affected = $wpdb->insert( $table_name, array( 
					'publicationuuid' => $pub_uuid, 
					'title' => $pub_title, 
					'personuuid' => $associated_person_uuid,
					'firstname' => $first_name, 
					'lastname' => $last_name, 
					'personrole' => $person_role_str,
					'retrieved' => $retrieved
				));
				
			}	
		
		}
	}
}	







